@@ -1,5 +1,5 @@
 use derive_more::From;
-use std::{error, fmt};
+use std::{error, fmt, str};
 use thiserror::Error;
 
 #[derive(Debug, Copy, Clone, Eq, PartialEq, From)]
@@ -40,6 +40,9 @@ pub enum PacketProtocolError {
     #[error(transparent)]
     Packet(#[from] PacketError),
 
+    #[error("Character array contains non-UTF-8 data")]
+    Utf8(#[from] str::Utf8Error),
+
     #[error("Packet contains a protocol violation")]
     ProtocolViolation,
 }
